"""
// © University of Southampton IT Innovation Centre, 2018
//
// Copyright in this software belongs to University of Southampton
// IT Innovation Centre of Gamma House, Enterprise Road,
// Chilworth Science Park, Southampton, SO16 7NS, UK.
//
// This software may not be used, sold, licensed, transferred, copied
// or reproduced in whole or in part in any manner or form or in or
// on any media by any person other than in accordance with the terms
// of the Licence Agreement supplied with the software, or otherwise
// without the prior written consent of the copyright owners.
//
// This software is distributed WITHOUT ANY WARRANTY, without even the
// implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE, except where stated in the Licence Agreement supplied with
// the software.
//
//      Created By :            Nikolay Stanchev
//      Created Date :          15-05-2018
//      Created for Project :   FLAME
"""

from json import loads


CONFIG_ATTRIBUTES = ('aggregator_running', 'aggregator_report_period', 'aggregator_database_name', 'aggregator_database_url')


def validate_content(configuration):
    """
    A utility function to validate a configuration string representing a JSON dictionary.

    :param configuration: the configuration string to validate
    :return the validated configuration dictionary object with the values converted to their required type
    :raise AssertionError: if the argument is not a valid configuration
    """

    global CONFIG_ATTRIBUTES

    configuration = configuration.replace('"aggregator_running": True', '"aggregator_running": true')
    configuration = configuration.replace('"aggregator_running":True', '"aggregator_running": true')
    configuration = configuration.replace('"aggregator_running": False', '"aggregator_running": false')
    configuration = configuration.replace('"aggregator_running":False', '"aggregator_running": false')

    try:
        configuration = loads(configuration)
    except:
        raise AssertionError("Configuration must be a JSON object.")

    assert len(configuration) == len(CONFIG_ATTRIBUTES), "Configuration mustn't contain more attributes than the required ones."

    for attribute in CONFIG_ATTRIBUTES:
        assert attribute in configuration

    assert type(configuration['aggregator_running']) == bool, "Boolean value expected for the 'aggregator_running' attribute, received {0} instead.".format(configuration.get('aggregator_running'))

    assert type(configuration['aggregator_report_period']) == int, "Report period must be an integer, received {0} instead.".format(configuration.get('aggregator_report_period'))

    return configuration
